@@ -1,3 +1,4 @@
+import inspect
 import json
 import logging
 import os
@@ -11,7 +12,7 @@ from pytest import fixture, FixtureRequest, hookimpl, Item, CallInfo, StashKey,
 from oar.client import Client
 from oar.models import EnvConfig, Test, Outcome, Analysis, Resolution, Results
 
-logger = logging.getLogger("oar messenger")
+logger = logging.getLogger("oar")
 
 phase_report_key = StashKey[dict[str, CollectReport]]()  # Stores result data to be available at the fixture level
 
@@ -68,8 +69,8 @@ def oar_test(request: FixtureRequest, oar_config, oar_results, oar_client) -> Te
     test_type = typing.get_type_hints(request.function).get(oar_test.__name__, Test)
 
     # Ensures that a test type is actually being used
-    if test_type != Test and Test not in test_type.__bases__:
-        raise TypeError("`oar_test` fixture type must inherit from `oar.Test`")
+    if test_type != Test and Test not in inspect.getmro(test_type):
+        raise TypeError(f"`oar_test` fixture type must inherit from `oar.Test` Bases: {inspect.getmro(test_type)}")
 
     # Initialize a base test container to yield back into the test to use, the specific type will be used later
     test = Test()
@@ -78,7 +79,8 @@ def oar_test(request: FixtureRequest, oar_config, oar_results, oar_client) -> Te
     # Initializes the specific test_type
     try:
         test = test_type(**test.dict())
-    except ValidationError:
+    except ValidationError as e:
+        logger.warning(e)
         return  # Will not report on validation errors
 
     # Appends a test type onto a test if it is a specific type
@@ -150,7 +152,7 @@ def oar_results(oar_config) -> Results:
     if not oar_config.store_results:
         return
 
-    results.calculate()
+    results.completed_time = str(datetime.utcnow())
     if oar_config.log_summary:
         results.log_summary_statistics()
 
